summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorjacobkeeler <jacob.keeler@livioradio.com>2019-02-26 10:33:24 -0500
committerjacobkeeler <jacob.keeler@livioradio.com>2019-02-26 10:33:24 -0500
commitf22342f5ad898d5783642e60dd40a83c79c545cf (patch)
treef1046afd8e311441bc7c7c8493563b4fa9f07a20
parent2d30ea5947b8503544764fe9806dd2ad25c5c519 (diff)
downloadsdl_core-feature/perform_app_service_interaction.tar.gz
Change PerformAppServiceInteraction class namingfeature/perform_app_service_interaction
Clarify direction in class name
-rw-r--r--src/components/application_manager/rpc_plugins/app_service_rpc_plugin/include/app_service_rpc_plugin/commands/hmi/as_perform_app_service_interaction_request_to_hmi.h (renamed from src/components/application_manager/rpc_plugins/app_service_rpc_plugin/include/app_service_rpc_plugin/commands/hmi/as_perform_app_service_interaction_request.h)20
-rw-r--r--src/components/application_manager/rpc_plugins/app_service_rpc_plugin/include/app_service_rpc_plugin/commands/hmi/as_perform_app_service_interaction_response_from_hmi.h (renamed from src/components/application_manager/rpc_plugins/app_service_rpc_plugin/include/app_service_rpc_plugin/commands/hmi/as_perform_app_service_interaction_response.h)20
-rw-r--r--src/components/application_manager/rpc_plugins/app_service_rpc_plugin/src/app_service_hmi_command_factory.cc13
-rw-r--r--src/components/application_manager/rpc_plugins/app_service_rpc_plugin/src/commands/hmi/as_perform_app_service_interaction_request_to_hmi.cc (renamed from src/components/application_manager/rpc_plugins/app_service_rpc_plugin/src/commands/hmi/as_perform_app_service_interaction_request.cc)21
-rw-r--r--src/components/application_manager/rpc_plugins/app_service_rpc_plugin/src/commands/hmi/as_perform_app_service_interaction_response_from_hmi.cc (renamed from src/components/application_manager/rpc_plugins/app_service_rpc_plugin/src/commands/hmi/as_perform_app_service_interaction_response.cc)21
5 files changed, 47 insertions, 48 deletions
diff --git a/src/components/application_manager/rpc_plugins/app_service_rpc_plugin/src/app_service_hmi_command_factory.cc b/src/components/application_manager/rpc_plugins/app_service_rpc_plugin/src/app_service_hmi_command_factory.cc
index 42a4238cc6..7cfbdd22d0 100644
--- a/src/components/application_manager/rpc_plugins/app_service_rpc_plugin/src/app_service_hmi_command_factory.cc
+++ b/src/components/application_manager/rpc_plugins/app_service_rpc_plugin/src/app_service_hmi_command_factory.cc
@@ -44,18 +44,14 @@
#include "app_service_rpc_plugin/commands/hmi/as_get_app_service_data_response_to_hmi.h"
#include "app_service_rpc_plugin/commands/hmi/as_get_app_service_records_request.h"
#include "app_service_rpc_plugin/commands/hmi/as_get_app_service_records_response.h"
-#include "app_service_rpc_plugin/commands/hmi/as_perform_app_service_interaction_request.h"
#include "app_service_rpc_plugin/commands/hmi/as_perform_app_service_interaction_request_from_hmi.h"
-#include "app_service_rpc_plugin/commands/hmi/as_perform_app_service_interaction_response.h"
+#include "app_service_rpc_plugin/commands/hmi/as_perform_app_service_interaction_request_to_hmi.h"
+#include "app_service_rpc_plugin/commands/hmi/as_perform_app_service_interaction_response_from_hmi.h"
#include "app_service_rpc_plugin/commands/hmi/as_perform_app_service_interaction_response_to_hmi.h"
#include "app_service_rpc_plugin/commands/hmi/as_publish_app_service_request.h"
#include "app_service_rpc_plugin/commands/hmi/as_publish_app_service_response.h"
#include "app_service_rpc_plugin/commands/hmi/on_as_app_service_data_notification.h"
#include "app_service_rpc_plugin/commands/hmi/on_as_app_service_data_notification_from_hmi.h"
-#include "app_service_rpc_plugin/commands/hmi/as_get_app_service_data_request_from_hmi.h"
-#include "app_service_rpc_plugin/commands/hmi/as_get_app_service_data_response_from_hmi.h"
-#include "app_service_rpc_plugin/commands/hmi/as_get_app_service_data_request_to_hmi.h"
-#include "app_service_rpc_plugin/commands/hmi/as_get_app_service_data_response_to_hmi.h"
CREATE_LOGGERPTR_GLOBAL(logger_, "AppServiceRpcPlugin")
@@ -169,12 +165,13 @@ app_mngr::CommandCreator& AppServiceHmiCommandFactory::buildCommandCreator(
commands::
ASPerformAppServiceInteractionRequestFromHMI>()
: factory.GetCreator<
- commands::ASPerformAppServiceInteractionResponse>();
+ commands::
+ ASPerformAppServiceInteractionResponseFromHMI>();
} else if (app_mngr::commands::Command::CommandSource::
SOURCE_SDL_TO_HMI == source) {
return hmi_apis::messageType::request == message_type
? factory.GetCreator<
- commands::ASPerformAppServiceInteractionRequest>()
+ commands::ASPerformAppServiceInteractionRequestToHMI>()
: factory.GetCreator<
commands::
ASPerformAppServiceInteractionResponseToHMI>();
diff --git a/src/components/application_manager/rpc_plugins/app_service_rpc_plugin/src/commands/hmi/as_perform_app_service_interaction_request.cc b/src/components/application_manager/rpc_plugins/app_service_rpc_plugin/src/commands/hmi/as_perform_app_service_interaction_request_to_hmi.cc
index 6efd5ec162..22876328de 100644
--- a/src/components/application_manager/rpc_plugins/app_service_rpc_plugin/src/commands/hmi/as_perform_app_service_interaction_request.cc
+++ b/src/components/application_manager/rpc_plugins/app_service_rpc_plugin/src/commands/hmi/as_perform_app_service_interaction_request_to_hmi.cc
@@ -30,28 +30,29 @@
POSSIBILITY OF SUCH DAMAGE.
*/
-#include "app_service_rpc_plugin/commands/hmi/as_perform_app_service_interaction_request.h"
+#include "app_service_rpc_plugin/commands/hmi/as_perform_app_service_interaction_request_to_hmi.h"
namespace app_service_rpc_plugin {
using namespace application_manager;
namespace commands {
-ASPerformAppServiceInteractionRequest::ASPerformAppServiceInteractionRequest(
- const application_manager::commands::MessageSharedPtr& message,
- ApplicationManager& application_manager,
- app_mngr::rpc_service::RPCService& rpc_service,
- app_mngr::HMICapabilities& hmi_capabilities,
- policy::PolicyHandlerInterface& policy_handler)
+ASPerformAppServiceInteractionRequestToHMI::
+ ASPerformAppServiceInteractionRequestToHMI(
+ const application_manager::commands::MessageSharedPtr& message,
+ ApplicationManager& application_manager,
+ app_mngr::rpc_service::RPCService& rpc_service,
+ app_mngr::HMICapabilities& hmi_capabilities,
+ policy::PolicyHandlerInterface& policy_handler)
: RequestToHMI(message,
application_manager,
rpc_service,
hmi_capabilities,
policy_handler) {}
-ASPerformAppServiceInteractionRequest::
- ~ASPerformAppServiceInteractionRequest() {}
+ASPerformAppServiceInteractionRequestToHMI::
+ ~ASPerformAppServiceInteractionRequestToHMI() {}
-void ASPerformAppServiceInteractionRequest::Run() {
+void ASPerformAppServiceInteractionRequestToHMI::Run() {
LOG4CXX_AUTO_TRACE(logger_);
SendRequest();
}
diff --git a/src/components/application_manager/rpc_plugins/app_service_rpc_plugin/src/commands/hmi/as_perform_app_service_interaction_response.cc b/src/components/application_manager/rpc_plugins/app_service_rpc_plugin/src/commands/hmi/as_perform_app_service_interaction_response_from_hmi.cc
index f8ddf511b4..a2ffa65a73 100644
--- a/src/components/application_manager/rpc_plugins/app_service_rpc_plugin/src/commands/hmi/as_perform_app_service_interaction_response.cc
+++ b/src/components/application_manager/rpc_plugins/app_service_rpc_plugin/src/commands/hmi/as_perform_app_service_interaction_response_from_hmi.cc
@@ -30,28 +30,29 @@
POSSIBILITY OF SUCH DAMAGE.
*/
-#include "app_service_rpc_plugin/commands/hmi/as_perform_app_service_interaction_response.h"
+#include "app_service_rpc_plugin/commands/hmi/as_perform_app_service_interaction_response_from_hmi.h"
namespace app_service_rpc_plugin {
using namespace application_manager;
namespace commands {
-ASPerformAppServiceInteractionResponse::ASPerformAppServiceInteractionResponse(
- const application_manager::commands::MessageSharedPtr& message,
- ApplicationManager& application_manager,
- app_mngr::rpc_service::RPCService& rpc_service,
- app_mngr::HMICapabilities& hmi_capabilities,
- policy::PolicyHandlerInterface& policy_handler)
+ASPerformAppServiceInteractionResponseFromHMI::
+ ASPerformAppServiceInteractionResponseFromHMI(
+ const application_manager::commands::MessageSharedPtr& message,
+ ApplicationManager& application_manager,
+ app_mngr::rpc_service::RPCService& rpc_service,
+ app_mngr::HMICapabilities& hmi_capabilities,
+ policy::PolicyHandlerInterface& policy_handler)
: ResponseFromHMI(message,
application_manager,
rpc_service,
hmi_capabilities,
policy_handler) {}
-ASPerformAppServiceInteractionResponse::
- ~ASPerformAppServiceInteractionResponse() {}
+ASPerformAppServiceInteractionResponseFromHMI::
+ ~ASPerformAppServiceInteractionResponseFromHMI() {}
-void ASPerformAppServiceInteractionResponse::Run() {
+void ASPerformAppServiceInteractionResponseFromHMI::Run() {
LOG4CXX_AUTO_TRACE(logger_);
event_engine::Event event(
hmi_apis::FunctionID::AppService_PerformAppServiceInteraction);
diff --git a/src/components/application_manager/rpc_plugins/app_service_rpc_plugin/include/app_service_rpc_plugin/commands/hmi/as_perform_app_service_interaction_request.h b/src/components/application_manager/rpc_plugins/app_service_rpc_plugin/include/app_service_rpc_plugin/commands/hmi/as_perform_app_service_interaction_request_to_hmi.h
index 22faf1b83c..0b67dd5624 100644
--- a/src/components/application_manager/rpc_plugins/app_service_rpc_plugin/include/app_service_rpc_plugin/commands/hmi/as_perform_app_service_interaction_request.h
+++ b/src/components/application_manager/rpc_plugins/app_service_rpc_plugin/include/app_service_rpc_plugin/commands/hmi/as_perform_app_service_interaction_request_to_hmi.h
@@ -30,8 +30,8 @@
POSSIBILITY OF SUCH DAMAGE.
*/
-#ifndef SRC_COMPONENTS_APPLICATION_MANAGER_RPC_PLUGINS_APP_SERVICE_RPC_PLUGIN_INCLUDE_APP_SERVICE_RPC_PLUGIN_COMMANDS_HMI_AS_PERFORM_APP_SERVICE_INTERACTION_REQUEST_H_
-#define SRC_COMPONENTS_APPLICATION_MANAGER_RPC_PLUGINS_APP_SERVICE_RPC_PLUGIN_INCLUDE_APP_SERVICE_RPC_PLUGIN_COMMANDS_HMI_AS_PERFORM_APP_SERVICE_INTERACTION_REQUEST_H_
+#ifndef SRC_COMPONENTS_APPLICATION_MANAGER_RPC_PLUGINS_APP_SERVICE_RPC_PLUGIN_INCLUDE_APP_SERVICE_RPC_PLUGIN_COMMANDS_HMI_AS_PERFORM_APP_SERVICE_INTERACTION_REQUEST_TO_HMI_H_
+#define SRC_COMPONENTS_APPLICATION_MANAGER_RPC_PLUGINS_APP_SERVICE_RPC_PLUGIN_INCLUDE_APP_SERVICE_RPC_PLUGIN_COMMANDS_HMI_AS_PERFORM_APP_SERVICE_INTERACTION_REQUEST_TO_HMI_H_
#include "app_service_rpc_plugin/app_service_rpc_plugin.h"
#include "application_manager/commands/request_to_hmi.h"
@@ -42,17 +42,17 @@ namespace app_mngr = application_manager;
namespace commands {
/**
* @brief ASPerformAppServiceInteractionRequest command class
**/
-class ASPerformAppServiceInteractionRequest
+class ASPerformAppServiceInteractionRequestToHMI
: public app_mngr::commands::RequestToHMI {
public:
/**
* @brief ASPerformAppServiceInteractionRequest class constructor
*
* @param message Incoming SmartObject message
**/
- ASPerformAppServiceInteractionRequest(
+ ASPerformAppServiceInteractionRequestToHMI(
const app_mngr::commands::MessageSharedPtr& message,
app_mngr::ApplicationManager& application_manager,
app_mngr::rpc_service::RPCService& rpc_service,
@@ -60,9 +60,9 @@ class ASPerformAppServiceInteractionRequest
policy::PolicyHandlerInterface& policy_handle);
/**
* @brief ASPerformAppServiceInteractionRequest class destructor
**/
- virtual ~ASPerformAppServiceInteractionRequest();
+ virtual ~ASPerformAppServiceInteractionRequestToHMI();
/**
* @brief Execute command
@@ -70,11 +70,11 @@ class ASPerformAppServiceInteractionRequest
virtual void Run();
private:
- DISALLOW_COPY_AND_ASSIGN(ASPerformAppServiceInteractionRequest);
+ DISALLOW_COPY_AND_ASSIGN(ASPerformAppServiceInteractionRequestToHMI);
};
} // namespace commands
} // namespace app_service_rpc_plugin
-#endif // SRC_COMPONENTS_APPLICATION_MANAGER_RPC_PLUGINS_APP_SERVICE_RPC_PLUGIN_INCLUDE_APP_SERVICE_RPC_PLUGIN_COMMANDS_HMI_AS_PERFORM_APP_SERVICE_INTERACTION_REQUEST_H_
+#endif // SRC_COMPONENTS_APPLICATION_MANAGER_RPC_PLUGINS_APP_SERVICE_RPC_PLUGIN_INCLUDE_APP_SERVICE_RPC_PLUGIN_COMMANDS_HMI_AS_PERFORM_APP_SERVICE_INTERACTION_REQUEST_TO_HMI_H_
@@ -42,17 +42,17 @@ namespace app_mngr = application_manager;
namespace commands {
/**
- * @brief ASPerformAppServiceInteractionRequest command class
+ * @brief ASPerformAppServiceInteractionRequestToHMI command class
**/
@@ -42,17 +42,17 @@ namespace app_mngr = application_manager;
public:
/**
- * @brief ASPerformAppServiceInteractionRequest class constructor
+ * @brief ASPerformAppServiceInteractionRequestToHMI class constructor
*
* @param message Incoming SmartObject message
@@ -60,9 +60,9 @@ class ASPerformAppServiceInteractionRequest
policy::PolicyHandlerInterface& policy_handle);
/**
- * @brief ASPerformAppServiceInteractionRequest class destructor
+ * @brief ASPerformAppServiceInteractionRequestToHMI class destructor
**/
diff --git a/src/components/application_manager/rpc_plugins/app_service_rpc_plugin/include/app_service_rpc_plugin/commands/hmi/as_perform_app_service_interaction_response.h b/src/components/application_manager/rpc_plugins/app_service_rpc_plugin/include/app_service_rpc_plugin/commands/hmi/as_perform_app_service_interaction_response_from_hmi.h
index 8f82f703dd..f807348833 100644
--- a/src/components/application_manager/rpc_plugins/app_service_rpc_plugin/include/app_service_rpc_plugin/commands/hmi/as_perform_app_service_interaction_response.h
+++ b/src/components/application_manager/rpc_plugins/app_service_rpc_plugin/include/app_service_rpc_plugin/commands/hmi/as_perform_app_service_interaction_response_from_hmi.h
@@ -30,8 +30,8 @@
POSSIBILITY OF SUCH DAMAGE.
*/
-#ifndef SRC_COMPONENTS_APPLICATION_MANAGER_RPC_PLUGINS_APP_SERVICE_RPC_PLUGIN_INCLUDE_APP_SERVICE_RPC_PLUGIN_COMMANDS_HMI_AS_PERFORM_APP_SERVICE_INTERACTION_RESPONSE_H_
-#define SRC_COMPONENTS_APPLICATION_MANAGER_RPC_PLUGINS_APP_SERVICE_RPC_PLUGIN_INCLUDE_APP_SERVICE_RPC_PLUGIN_COMMANDS_HMI_AS_PERFORM_APP_SERVICE_INTERACTION_RESPONSE_H_
+#ifndef SRC_COMPONENTS_APPLICATION_MANAGER_RPC_PLUGINS_APP_SERVICE_RPC_PLUGIN_INCLUDE_APP_SERVICE_RPC_PLUGIN_COMMANDS_HMI_AS_PERFORM_APP_SERVICE_INTERACTION_RESPONSE_FROM_HMI_H_
+#define SRC_COMPONENTS_APPLICATION_MANAGER_RPC_PLUGINS_APP_SERVICE_RPC_PLUGIN_INCLUDE_APP_SERVICE_RPC_PLUGIN_COMMANDS_HMI_AS_PERFORM_APP_SERVICE_INTERACTION_RESPONSE_FROM_HMI_H_
#include "app_service_rpc_plugin/app_service_rpc_plugin.h"
#include "application_manager/commands/response_from_hmi.h"
@@ -42,17 +42,17 @@ namespace app_mngr = application_manager;
namespace commands {
/**
* @brief ASPerformAppServiceInteractionResponse command class
**/
-class ASPerformAppServiceInteractionResponse
+class ASPerformAppServiceInteractionResponseFromHMI
: public app_mngr::commands::ResponseFromHMI {
public:
/**
* @brief ASPerformAppServiceInteractionResponse class constructor
*
* @param message Incoming SmartObject message
**/
- ASPerformAppServiceInteractionResponse(
+ ASPerformAppServiceInteractionResponseFromHMI(
const app_mngr::commands::MessageSharedPtr& message,
app_mngr::ApplicationManager& application_manager,
app_mngr::rpc_service::RPCService& rpc_service,
@@ -60,9 +60,9 @@ class ASPerformAppServiceInteractionResponse
policy::PolicyHandlerInterface& policy_handle);
/**
* @brief ASPerformAppServiceInteractionResponse class destructor
**/
- virtual ~ASPerformAppServiceInteractionResponse();
+ virtual ~ASPerformAppServiceInteractionResponseFromHMI();
/**
* @brief Execute command
@@ -70,11 +70,11 @@ class ASPerformAppServiceInteractionResponse
virtual void Run();
private:
- DISALLOW_COPY_AND_ASSIGN(ASPerformAppServiceInteractionResponse);
+ DISALLOW_COPY_AND_ASSIGN(ASPerformAppServiceInteractionResponseFromHMI);
};
} // namespace commands
} // namespace app_service_rpc_plugin
-#endif // SRC_COMPONENTS_APPLICATION_MANAGER_RPC_PLUGINS_APP_SERVICE_RPC_PLUGIN_INCLUDE_APP_SERVICE_RPC_PLUGIN_COMMANDS_HMI_AS_PERFORM_APP_SERVICE_INTERACTION_RESPONSE_H_
+#endif // SRC_COMPONENTS_APPLICATION_MANAGER_RPC_PLUGINS_APP_SERVICE_RPC_PLUGIN_INCLUDE_APP_SERVICE_RPC_PLUGIN_COMMANDS_HMI_AS_PERFORM_APP_SERVICE_INTERACTION_RESPONSE_FROM_HMI_H_
@@ -42,17 +42,17 @@ namespace app_mngr = application_manager;
namespace commands {
/**
- * @brief ASPerformAppServiceInteractionResponse command class
+ * @brief ASPerformAppServiceInteractionResponseFromHMI command class
**/
@@ -42,17 +42,17 @@ namespace app_mngr = application_manager;
public:
/**
- * @brief ASPerformAppServiceInteractionResponse class constructor
+ * @brief ASPerformAppServiceInteractionResponseFromHMI class constructor
*
* @param message Incoming SmartObject message
@@ -60,9 +60,9 @@ class ASPerformAppServiceInteractionResponse
policy::PolicyHandlerInterface& policy_handle);
/**
- * @brief ASPerformAppServiceInteractionResponse class destructor
+ * @brief ASPerformAppServiceInteractionResponseFromHMI class destructor
**/